<?php
/**
 * Navigation Menu widget class
 *
 * @since 3.0.0
 */
 class TCKR_Mailchimp_Widget extends WP_Widget {
	var $data = '';
 
	function __construct() {
		$widget_ops = array( 'description' => __('Use this widget to add a mailchimp newsletter to your site.',THEMENAME) );
		parent::__construct( 'tckr_mailchimp', __('['.THEMENAME.'] Mailchimp Newsletter',THEMENAME), $widget_ops );
		global $data;
		$this->data = $data;
	}
	
	function widget($args, $instance) {
		
		$data = $this->data;
		$instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		if ( isset ( $_POST['tckr_mc_email']) ) {
			
			
			if ( isset ( $data['mailchimp_api'] ) && !empty ( $data['mailchimp_api'] ) ) {
			
				if ( !class_exists( 'MCAPI' ) ) {
					include_once (TEMPLATEPATH . '/widgets/mailchimp/MCAPI.class.php');
				}
				
				$api_key = $data['mailchimp_api'];
				
				$mcapi = new MCAPI($api_key);
				
				$merge_vars = Array( 
					'EMAIL' => $_POST['tckr_mc_email']
				);
				
				$list_id = $instance['tckr_mailchimp_list'];
				
				if($mcapi->listSubscribe($list_id, $_POST['tckr_mc_email'], $merge_vars ) ) {
					// It worked!   
					$msg = '<span style="color:green;">'.__('Success!&nbsp; Check your inbox or spam folder for a message containing a confirmation link.',THEMENAME).'</span>';
				}else{
					// An error ocurred, return error message   
					$msg = '<span style="color:red;"><b>'.__('Error:',THEMENAME).'</b>&nbsp; ' . $mcapi->errorMessage.'</span>';
					
				}
				
			}

		}
		
		if (empty($data['mailchimp_api'])){

			echo	'<div class="newsletter-signup">';
			echo '<p>No mailchimp list selected. Please set your mailchimp API key in the theme admin panel and then configure the widget from the widget options.</p>';
			echo	'	</div><!-- end newsletter-signup -->';

			return;
		}
		
		echo $args['before_widget'];

		echo	'<div class="newsletter-signup">';
		
		if ( !empty($instance['title']) )
			echo $args['before_title'] . $instance['title'] . $args['after_title'];

		// GET INTRO TEXT
		if ( ! empty( $instance['tckr_mailchimp_intro'] ) ) {
			echo	'<p>'.$instance['tckr_mailchimp_intro'].'</p>';
		}

		echo	'		<form method="post" class="newsletter_subscribe newsletter-signup" data-url="'.trailingslashit(home_url()).'" name="newsletter_form">';
		echo	'			<input type="text" name="tckr_mc_email" class="nl-email" value="" placeholder="'.__("your.address@email.com",THEMENAME).'" />';
		echo	'			<input type="hidden" name="tckr_list_class" class="nl-lid" value="'.$instance['tckr_mailchimp_list'].'" />';
		echo	'			<input type="submit" name="submit" class="nl-submit" value="'.__("JOIN US",THEMENAME).'" />';
		echo	'		</form>';
		
		if ( isset ( $msg ) ) {
			echo '<span class="tckr_mailchimp_result">'.$msg.'</span>';
		}
		else {
			echo	'		<span class="tckr_mailchimp_result"></span>';
		}

		// GET INTRO TEXT
		if ( ! empty( $instance['tckr_mailchimp_outro'] ) )	{
			echo	'<p>'.$instance['tckr_mailchimp_outro'].'</p>';
		}
			
		echo	'	</div><!-- end newsletter-signup -->';
		echo $args['after_widget'];
		
		//global $data;
		//print_r($data);
	}

	function update( $new_instance, $old_instance ) {
		$instance['title'] = strip_tags( stripslashes($new_instance['title']) );
		$instance['tckr_mailchimp_intro'] =  stripslashes($new_instance['tckr_mailchimp_intro']) ;
		$instance['tckr_mailchimp_outro'] =  stripslashes($new_instance['tckr_mailchimp_outro']) ;
		$instance['tckr_mailchimp_list'] = $new_instance['tckr_mailchimp_list'];
		return $instance;
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$tckr_mailchimp_intro = isset( $instance['tckr_mailchimp_intro'] ) ? $instance['tckr_mailchimp_intro'] : '';
		$tckr_mailchimp_outro = isset( $instance['tckr_mailchimp_outro'] ) ? $instance['tckr_mailchimp_outro'] : '';
		$tckr_mailchimp_list = isset( $instance['tckr_mailchimp_list'] ) ? $instance['tckr_mailchimp_list'] : '';
		$data = $this->data;

		if ( !function_exists('curl_init') ) {
			echo __('Curl is not enabled on your hosting environment. Please contact your hosting company and ask them to enable CURL for your account.',THEMENAME);
			return;
		}
		
		if ( !isset ( $data['mailchimp_api'] ) && empty ( $data['mailchimp_api'] ) ) {
			echo __('Please enter your MailChimp API KEY in the theme options pannel prior of using this widget.',THEMENAME);
			return;
		}
		
		
		if ( isset ( $data['mailchimp_api'] ) && !empty ( $data['mailchimp_api'] ) ) {
				if ( !class_exists( 'MCAPI' ) ) {
					include_once (TEMPLATEPATH . '/widgets/mailchimp/MCAPI.class.php');
				}
			$api_key = $data['mailchimp_api'];
			
			$mcapi = new MCAPI($api_key);
			
			$lists = $mcapi->lists();
		}
			
		//print_r($lists);
		
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:',THEMENAME) ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('tckr_mailchimp_list'); ?>"><?php _e('Select List:',THEMENAME); ?></label>
			<select id="<?php echo $this->get_field_id('tckr_mailchimp_list'); ?>" name="<?php echo $this->get_field_name('tckr_mailchimp_list'); ?>">
			
			<?php	
			if ( isset($lists['data']) && is_array($lists['data'])) {
				foreach ($lists['data'] as $key => $value) {
					$selected = (isset($tckr_mailchimp_list) && $tckr_mailchimp_list == $value['id']) ? ' selected="selected" ' : '';
					?>	
						<option <?php echo $selected; ?>value="<?php echo $value['id']; ?>"><?php echo $value['name']; ?></option>
					<?php
				}
			}
			?>
			
			</select>
		</p>
		
		<p>
			<div><label for="<?php echo $this->get_field_id('tckr_mailchimp_intro'); ?>"><?php echo __('Intro Text :',THEMENAME); ?></label></div>
			<div><textarea id="<?php echo $this->get_field_id('tckr_mailchimp_intro'); ?>" name="<?php echo $this->get_field_name('tckr_mailchimp_intro'); ?>" cols="35" rows="5"><?php echo $tckr_mailchimp_intro; ?></textarea></div>
		</p>
		<p>
			<div><label for="<?php echo $this->get_field_id('tckr_mailchimp_outro'); ?>"><?php echo __('After Form Text :',THEMENAME); ?></label></div>
			<div><textarea id="<?php echo $this->get_field_id('tckr_mailchimp_outro'); ?>" name="<?php echo $this->get_field_name('tckr_mailchimp_outro'); ?>" cols="35" rows="5"><?php echo $tckr_mailchimp_outro; ?></textarea></div>
		</p>

		<?php
	}
}


add_action( 'widgets_init', create_function( '', 'register_widget( "TCKR_Mailchimp_Widget" );' ) );


/*--------------------------------------------------------------------------------------------------
	Mailchimp ajax helper
--------------------------------------------------------------------------------------------------*/
		
	function tckr_do_action(){
		if ( isset ( $_POST['tckr_ajax'] ) ) {
			if (!headers_sent()){ //just in case...
				header('Last-Modified: '.gmdate('D, d M Y H:i:s').' GMT', true, 200);
			}
			
				if ( isset ( $_POST['tckr_mc_email']) ) {
					
					global $data;
										
					if ( isset ( $data['mailchimp_api'] ) && !empty ( $data['mailchimp_api'] ) ) {
					
						include_once (TEMPLATEPATH . '/widgets/mailchimp/MCAPI.class.php');
						$api_key = $data['mailchimp_api'];
						
						$mcapi = new MCAPI($api_key);
						
						$merge_vars = Array( 
							'EMAIL' => $_POST['tckr_mc_email']
						);
						
						$list_id = $_POST['tckr_mailchimp_list'];
						
						if($mcapi->listSubscribe($list_id, $_POST['tckr_mc_email'], $merge_vars ) ) {
							// It worked!   
							$msg = '<span style="color:green;">'.__('Success!&nbsp; Check your inbox or spam folder for a message containing a confirmation link.',THEMENAME).'</span>';
						}else{
							// An error ocurred, return error message   
							$msg = '<span style="color:red;"><b>'.__('Error:',THEMENAME).'</b>&nbsp; ' . $mcapi->errorMessage.'</span>';
							
						}
						
						
					}

				}
			
			echo $msg; // Don't esc_html this, b/c we've already escaped it
			exit;
		}
	}
	
	add_action('init', 'tckr_do_action');

?>